@@ -70,6 +70,20 @@ class GitProject:
         parse = GitProject.git_url_parse()
         return f'{parse.scheme}://{parse.hostname}{parse.path}'
 
+    def push_changelog(self, changelog, file_name="CHANGELOG.md"):
+        data = {
+            'branch': self.branch,
+            'commit_message': 'changelog prepare to release',
+            'actions': [
+                {
+                    'action': 'update',
+                    'file_path': file_name,
+                    'content': changelog.text()
+                },
+            ]
+        }
+        self.gitlab_project.commits.create(data)
+
     def _get_master_branch(self):
         return self.gitlab_project.default_branch
 
